LINE Pay API SDK for Python
=================================

.. image:: https://img.shields.io/pypi/v/line-pay.svg
    :target: https://pypi.python.org/pypi/line-pay/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/wheel/line-pay.svg
    :target: https://pypi.python.org/pypi/line-pay/

.. image:: https://img.shields.io/pypi/pyversions/line-pay.svg
    :target: https://pypi.python.org/pypi/line-pay/

.. image:: https://img.shields.io/pypi/l/line-pay.svg
    :target: https://pypi.python.org/pypi/line-pay/


SDK of the LINE Pay API for Python.

Introduction
------------
The LINE Pay API SDK for Python makes it easy to develop apps using LINE Pay API.


API Documentation
-----------------

See the official API documentation for more information

English: https://pay.line.me/jp/developers/apis/onlineApis?locale=en_US

Japanese: https://pay.line.me/jp/developers/apis/onlineApis?locale=ja_JP

Requirements
------------

-  Python >= 3.6

Installation
------------

::

    $ pip install line-pay

Hints
-----

Examples
~~~~~~~~

`Example usage <https://github.com/sumihiro3/line-pay-sdk-python/tree/master/examples>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Example using `Flask <http://flask.pocoo.org/>`__
